require(MASS); require(mgcv); 

trimr<- function (a,n1,n2) {
  da<-dim(a); 
  if(is.null(da)) {a[(n1+1):(length(a)-n2)]}
  else {a[(n1+1):(da[1]-n2),]};
}

panelLabel=function(text) mtext(text,side=3,adj=0,cex=1.1,line=0.5); 

X=as.matrix(read.table("fitfunc.out"))
eco=X[,1]; evo=X[,2]; y=X[,3]; 

yrs=c(79,81:87); efx=matrix(0,7,2); 
x=matrix(c(0,0,1,1,0,1,0,1),4,2); 

for(j in 1:7) {
	j1=j; j2=j+1; 
	yvals=rep(0,4); 
	yvals[1]=y[(eco==j1)&(evo==j1)];
	yvals[2]=y[(eco==j1)&(evo==j2)];
	yvals[3]=y[(eco==j2)&(evo==j1)];
	yvals[4]=y[(eco==j2)&(evo==j2)];
	fit=lm(yvals~x[,1]+x[,2])
	efx[j,]=coef(fit)[-1]
	efx[j,]=efx[j,]/(yrs[j2]-yrs[j1]); 
}; 
z=apply(abs(efx),2,mean); z[2]/z[1];

graphics.off(); 
dev.new(height=8.5,width=5);  
par(mfrow=c(3,1),cex.axis=1.2,cex.lab=1.4,mgp=c(2.5,1,0),mar=c(4,5,2,1)); 
matplot(trimr(yrs,0,1)+1901,efx,type="o",col=c("forestgreen","blue"),lty=1,pch=c(15,16),lwd=2,
xlab="",ylab="Contributions",cex=1.8); 
legend("topleft",c("EVO","ECO"),col=c("blue","forestgreen"),lty=1,pch=c(16,15),lwd=2,bty="n",cex=1.35) 
title("Copepod EVO:ECO = 0.27",line=0.5); 
abline(h=0,lty=2); 
panelLabel("(a)"); 

source("gradfuncs.R"); 

G=read.csv("GeospizaData.csv");  
G$PC1.BodySize[6]=mean(G$PC1.BodySize[c(5,7)])
G$PC1.BeakSize[6]=mean(G$PC1.BeakSize[c(5,7)])
G$PC2.BeakShape[6]=mean(G$PC2.BeakShape[c(5,7)])

nyrs=dim(G)[1]; 
N=G$Population.size; r=log(N[2:nyrs])-log(N[1:(nyrs-1)]); r=c(r,NA);
G$Population.growth=r; 

G$frac.Large=G$Large.seeds/(G$Large.seeds+G$Small.seeds); 
G$Seeds=G$Large.seeds+G$Small.seeds

G$Size=0.5*(G$PC1.BodySize+G$PC1.BeakSize); 
G0=G[G$Year>=1976,]; 

fit.rain=gcv.rssM(log10(G0$Rainfall),G0$Population.growth, 
Boundary.knots=c(0,3.2),hmin=-2,hmax=1,intercept=T,penalty=1,ncongrid=NA,tol=0.001,draw=F)
px=seq(0,3.2,by=0.05); py=predict.rss(fit.rain$model,px); 

#### Ideal seed-size relationship
X=na.omit(cbind(G0$Year,G0$frac.Large,G0$Size));
e=is.element(X[,1],c(1978:1982,1988:1991));
X0=X[e,2:3]; 
fit.size.seed=lm(X0[,2]~X0[,1]); 
predict.size.seed=function(x) {coef=fit.size.seed$coef; coef[1]+coef[2]*x}

Y=subset(G0,select=c(Year,frac.Large,Size,PC2.BeakShape,Population.growth,Rainfall,Seeds)); 
Y=na.omit(Y); 

#resid.size=Y$Size-predict.size.seed(Y$frac.Large); 
#resid.rain=Y$Population.growth-predict.rss(fit.rain$model,log10(Y$Rainfall))$y 

# fits using MGCV 
fit3.size=gam(Population.growth~s(log(Rainfall))+Size+frac.Large+I(Size^2)+I(Size*frac.Large),data=Y); 

# compute contributions based on fit3 
a.z=coef(fit3.size)[2]; a.f=coef(fit3.size)[3];
a.z2=coef(fit3.size)[4]; a.zf=coef(fit3.size)[5];   
ft=G0$frac.Large[1:16]; zt=G0$Size[1:16]; 
drdz= a.z+2*a.z2*zt+a.zf*ft;  
drdf= a.f+a.zf*zt; 
dfdt=diff(ft); dzdt=diff(zt); 
zterm=drdz[1:15]*dzdt; fterm=drdf[1:15]*dfdt; 

matplot(G0$Year[1:15],cbind(fterm,zterm),type="o", pch=c(15,16), col=c("forestgreen","blue"),
lwd=2,lty=1,xlab="Year",ylab="Contributions",cex=1.8); 
abline(h=0,lty=2); 
title("Finch EVO:ECO = 2.2",line=0.5); 
panelLabel("(b)"); 

load("ChlamyEVOECO.Rdata"); 
par(yaxs="i"); 
matplot(EE$x,EE$y,type="o",lty=1,lwd=2,pch=c(1,16),col=c("green3","red"),ylim=c(0,1.05*max(EE$y)),
xlab="Environmental Forcing Period (days)",ylab="EVO:ECO",cex=1.8); 
legend("topleft",legend=c("Bottom-up","Top-down"),lty=1,lwd=2,col=c("green3","red"),
pch=c(1,16),cex=1.5,pt.cex=1.8,bty="n"); 
title("Nutrient-prey-predator model"); 
panelLabel("(c)"); 


