require(deSolve); 

####################################################################
# Two-prey-clone version of Brachionus/Chlamy model, with
# rotifer stage structure and 'Real Rotifer Functional Response' 
# Parameters are for algae in 10^4 cells/ml, rotifers in #/ml   
#################################################################### 
dy=numeric(5) 
ChemoDE=function(t,y,parms){
	pvalues=c(p1,1);  Kcvalues=c(k1,k2); P=parms[1]; 
	nt=y[1]; c1=y[2]; c2=y[3]; b=y[4]; s=y[5]; 
	
    # Derived parameters specific to each time point:
	fN=rho*nt/(Kcvalues+nt);
	Q=p1*c1+c2; p=Q/(c1+c2); C=c1+c2;   
    fB=G/(kB+max(Q,Qstar)); 
	tt=t-14; tt=tfun(tt); 
	rfac=1+eps.N*sqcos(2*pi*tt/P)*(t>14); 
	mt= eps.m*(1+sqcos(2*pi*tt/P))*(t>14); 
 	dy[1]= delta*(NI*rfac-nt) - fN[1]*c1 - fN[2]*c2;  	#N			
	dy[2]= c1*(chiC*fN[1] - p1*(b+s)*fB - delta);   #Clone 1
	dy[3]= c2*(chiC*fN[2] - (b+s)*fB - delta);      #Clone 2
	dy[4]= b*(chiB*Q*fB - (delta + m + mt + lambda) )    #Breeding rotifers
	dy[5]= lambda*b - (delta+ m + mt)*s                  #Senescent rotifers
	if(Q>Qstar) {
	      dXdk=p*chiB*G*kB/(kB+p*C)^2;
		  dXdz=C*chiB*G*kB/(kB+p*C)^2;
	}else{
		 dXdk=p*chiB*G/(kB+Qstar)
	     dXdz=C*chiB*G/(kB+Qstar)
	}
	dkdt=dy[2]+dy[3];
	dzdt=(p1-1)*(y[2]*dy[3]-y[3]*dy[2])/C^2
	eco=dXdk*dkdt; evo=dXdz*dzdt;  
	return(list(xdot=dy,mt,rfac,eco,evo))
} 

########## parameter estimates
p1=0.05; 
m=0.05; lambda=0.4; 
chiC=0.27; rho=2.70;
G=1.1; chiB=1.80; kB=5; 
Qstar=20;  
betaB=chiB*G; 

k1=4; k2=2; 
NI=80; delta=0.4

## turn cosine into square wave
sqcos=function(t) {x=sin(t); return(-1+2*exp(12*x)/(1+exp(12*x)))}

cv = 0.2; 

########################### Plot predator-trait dynamics 
xstart=c(5,5,5,.1,.1);
y0=as.vector(xstart); 
names(y0)<-c("N","C1","C2","B","S");

####### top-down 
eps.N=0; eps.m=0.2; 
T=16; tmax=14+8*T; times=seq(0,tmax,by=0.2); 
durations=c(0,cumsum(exp(rnorm(250,mean=log(T/2),sd=cv)))); 
markers=(T/2)*(0:250); 
tfun=approxfun(durations,markers,rule=2); 	

out=lsoda(y0, times, ChemoDE, parms=T);
c1=out[,3]; c2=out[,4]; R=out[,5]+out[,6]; C=c1+c2; pbar=c1/(c1+c2); 
BB=list(0); 
BB$x=times; BB$y=cbind(C/mean(C),R/mean(R)); BB$z=pbar; BB$f=out[,7]; 

############# bottom-up
eps.N=0.35; eps.m=0; 
T=16; tmax=14+8*T; times=seq(0,tmax,by=0.2); 
out=lsoda(y0, times, ChemoDE, parms=T);
c1=out[,3]; c2=out[,4]; R=out[,5]+out[,6]; C=c1+c2; pbar=c1/(c1+c2); 
CC=list(0); 
CC$x=times; CC$y=cbind(C/mean(C),R/mean(R)); CC$z=pbar; CC$f=out[,8]; 


######### Response period and Evo:Eco 
xstart=c(5,5,5,.1,.1);
y0=as.vector(xstart); 
names(y0)<-c("N","C1","C2","B","S");
######## Bottom-up; 
eps.N=0.35; eps.m=0; 
RT=CT=zT=Tvals=evofrac=seq(4,60,by=2); 
for(j in seq_along(Tvals)) {
	P=Tvals[j]; tmax=14+30*P; times=seq(0,tmax,by=0.1); 
	
	durations=c(0,cumsum(exp(rnorm(250,mean=log(P/2),sd=cv)))); 
	markers=(P/2)*(0:250); 
	tfun=approxfun(durations,markers,rule=2); 	
	
	out=lsoda(y0, times, ChemoDE, parms=P);
	c1=out[,3]; c2=out[,4]; R=out[,5]+out[,6]; C=c1+c2; pbar=c1/(c1+c2); 
	e=(times>80); etimes=times[e];

	Ct=ts(data = C[e], start = min(etimes), end = max(etimes), 
    deltat = etimes[2]-etimes[1], ts.eps = getOption("ts.eps"), class = "ts")
	out1=spectrum(Ct,spans=c(3,3),plot=FALSE,fast=FALSE); 
	jmax=which(out1$spec==max(out1$spec));
	CT[j]=1/out1$freq[jmax]; 
	
	Rt=ts(data = R[e], start = min(etimes), end = max(etimes), 
    deltat = etimes[2]-etimes[1], ts.eps = getOption("ts.eps"), class = "ts")
	out2=spectrum(Rt,spans=c(3,3),plot=FALSE,fast=FALSE); 
	jmax=which(out2$spec==max(out2$spec));
	RT[j]=1/out2$freq[jmax]; 
	
	zt=ts(data = pbar[e], start = min(etimes), end = max(etimes), 
    deltat = etimes[2]-etimes[1], ts.eps = getOption("ts.eps"), class = "ts")
	out3=spectrum(zt,spans=c(3,3),plot=FALSE,fast=FALSE); 
	jmax=which(out3$spec==max(out3$spec));
	zT[j]=1/out3$freq[jmax]; 
	
	evofrac[j]=mean(abs(out[e,10]))/mean(abs(out[e,9]));;
	cat(P,CT[j],RT[j],zT[j],evofrac[j],"\n");
}	

DD=list(0); 
DD$x=Tvals[1:16]; DD$y=cbind(CT,RT,zT); DD$y=DD$y[1:16,]; 

######## Top-down; 
eps.N=0; eps.m=0.25; 
evofracTop=seq_along(Tvals); 
for(j in seq_along(Tvals)) {
	P=Tvals[j]; tmax=14+20*P; times=seq(0,tmax,by=0.5); 
	durations=c(0,cumsum(exp(rnorm(50,mean=log(P/2),sd=cv)))); 
	markers=(P/2)*(0:50);  
	tfun=approxfun(durations,markers,rule=2); 	
	
	
	out=lsoda(y0, times, ChemoDE, parms=P);
	c1=out[,3]; c2=out[,4]; R=out[,5]+out[,6]; C=c1+c2; pbar=c1/(c1+c2); 
	e=(times>80); etimes=times[e];
	
	evofracTop[j]=mean(abs(out[e,10]))/mean(abs(out[e,9]));;
	cat(P,evofracTop[j],"\n");
}	
EE=list(0); 
EE$x=Tvals; EE$y=cbind(evofrac,evofracTop); 

save.image(file="ChlamyEVOECO.Rdata")



