Jgro=read.csv("LakeConstanceJuvenileGrowthRates.csv");
Asize=read.csv("LakeConstanceAdultSize.csv");

require(gplots); 
require(grDevices); require(graphics)
panelLabel=function(text) mtext(text,side=3,adj=0,cex=1.25,line=0.1); 

graphics.off(); 

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
## Data Frame with Adult Size (mg, NOT logged) by Food x Period 
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Sort adults wts on poor food by Juv Growth Rate 
Asize.Poor <- Asize[Asize$Food=="Poor",]; 
e <- order(Asize.Poor$Log.juvenile.growth.rate);
Asize.Poor <- Asize.Poor[e,];

# sort JGR on poor food 
e<- order(Jgro$BadFood); 
Jgro.Poor <- Jgro[e,]; 

# merge the data sets 
Asize.Poor$Period <- Jgro.Poor$Period;

# Sort adults wts on good food by Juv Growth Rate 
Asize.Good <- Asize[Asize$Food=="Good",]; 
e <- order(Asize.Good$Log.juvenile.growth.rate);
Asize.Good <- Asize.Good[e,];

# sort JGR on poor food 
e<- order(Jgro$GoodFood); 
Jgro.Good <- Jgro[e,]; 

Asize.Good$Period <- Jgro.Good$Period;
Asize.all <- rbind(Asize.Poor,Asize.Good); 
Asize.all$AdSize<- 10^(Asize.all$Log.adult.wt.mg);

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
## Plotting Juvenile Growth Rate 
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
nlog=function(x) (x)
se=function(x) sd(x)/sqrt(length(x)-1)

JB <- Jgro[Jgro$Period=="Before",]; 
JB.mean=c(mean(nlog(JB$GoodFood)),mean(nlog(JB$BadFood))); 
JB.se=c(se(nlog(JB$GoodFood)),se(nlog(JB$BadFood))); 

JA <- Jgro[Jgro$Period=="After",]; 
JA.mean=c(mean(nlog(JA$GoodFood)),mean(nlog(JA$BadFood)));
JA.se=c(se(nlog(JA$GoodFood)),se(nlog(JA$BadFood))); 

dev.new(width=9,height=4); 
par(xaxt="n",cex.axis=1.35,cex.lab=1.35,mar=c(4,5,2,1),mfrow=c(1,2)); 

plotCI(x=c(1.1,1.9),y=JB.mean,liw=JB.se,uiw=JB.se,type="b",lty=1,pch=1,
        ylim=c(0.23,0.47),xlab="",ylab="Juvenile Growth Rate (1/d)",xlim=c(1,2),lwd=2,cex=1.65);

par(new=TRUE); 

plotCI(x=c(1.1,1.9),y=JA.mean,liw=JA.se,uiw=JA.se,type="b",lty=1,pch=2,col="red",
ylim=c(0.23,0.47),xlab="",ylab="Juvenile Growth Rate (1/d)",xlim=c(1,2),lwd=2,cex=1.65);
par(xaxt="s"); 
axis(side=1,at=c(1.1,1.9),labels=c("Good Food","Poor Food"));

legend("topright",legend=c("Before (1962-71)","After (1992-97)"),
       pch=c(1,2),col=c(1,2),lty=1,bty="n",pt.cex=1.5,lwd=2,cex=1.25); 

h=(JB.mean[1]+JA.mean[2])/2; 
points(c(1.1,1.9),c(h,h),type="l",lty=2,lwd=2,col="blue"); 
panelLabel("(a)"); 

##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
## Plotting Adult Body Size: NOT log transformed 
##~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
AB <- Asize.all[Asize.all$Period=="Before",]; 
AB.Good <- AB[AB$Food=="Good",]; 
AB.Poor <- AB[AB$Food=="Poor",];
AB.mean <-c(mean(AB.Good$AdSize),mean(AB.Poor$AdSize)); 
AB.se <-c(se(AB.Good$AdSize),se(AB.Poor$AdSize)); 

AD <- Asize.all[Asize.all$Period=="During",]; 
AD.Good <- AD[AD$Food=="Good",]; 
AD.Poor <- AD[AD$Food=="Poor",];
AD.mean <-c(mean(AD.Good$AdSize),mean(AD.Poor$AdSize)); 
AD.se <-c(se(AD.Good$AdSize),se(AD.Poor$AdSize)); 

### 'after' is really after 
AA <- Asize.all[Asize.all$Period=="After",]; 
AA.Good <- AA[AA$Food=="Good",]; 
AA.Poor <- AA[AA$Food=="Poor",];
AA.mean <-c(mean(AA.Good$AdSize),mean(AA.Poor$AdSize)); 
AA.se <-c(se(AA.Good$AdSize),se(AA.Poor$AdSize)); 

ECO=((AB.mean[1]+AA.mean[1])-(AB.mean[2]+AA.mean[2]))/2; 
EVO=mean(AA.mean)-mean(AB.mean); 
cat(EVO/ECO);

par(xaxt="n"); 
plotCI(x=c(1.1,1.9),y=AB.mean,liw=AB.se,uiw=AB.se,type="b",lty=1,pch=1,lwd=2,
	ylim=c(0.015,0.035), xlab="",ylab="Adult Size (mg)",xlim=c(1,2),cex=1.65);

par(new=TRUE); 
plotCI(x=c(1.12,1.92),y=AA.mean,liw=AA.se,uiw=AA.se,type="b",lty=1,pch=2,col="red",lwd=2,
ylim=c(0.015,0.035),xlab="",ylab="Adult Size (mg)",xlim=c(1,2),cex=1.65);
par(xaxt="s"); 
axis(side=1,at=c(1.1,1.9),labels=c("Good Food","Poor Food"));

panelLabel("(b)"); 

###~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
# Does genotype matter for Adult wt? 
###~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
fitA=lm(Log.adult.wt.mg~Log.juvenile.growth.rate + factor(Period)*factor(Food),
        data=Asize.all);

summary(fitA);

fitA0=lm(Log.adult.wt.mg~Log.juvenile.growth.rate + factor(Food),
        data=Asize.all);

summary(fitA0);

AIC(fitA,fitA0); 

Asize.bd <- Asize.all[Asize.all$Period!="After",];
fitAbd=lm(Log.adult.wt.mg~Log.juvenile.growth.rate + factor(Period) + factor(Food),
        data=Asize.bd);

summary(fitAbd);

############################################
x <- seq(-1, 0, length = 10)
y <- seq(0,1,length=10)
Asizefun <- function(x,y){-1.38 + 0.75*x + 0.13*y}
z <- outer(x, y, Asizefun)

dev.new(height=7,width=7)
par(cex.axis=1,cex.lab=1.4,yaxt="n",mar=c(0,4,0,2)); 
pmat=persp(x, y, z, theta = 20, phi = 20, expand = 0.5, col = "gray80",
      ltheta = 120, shade = 0.175, ticktype = "detailed",zlim=c(-2.5,-1),
      xlab = "Log10 Juv Growth Rate", ylab = "Food Quality", 
	zlab = "Log10 Adult Weight (mg)")

points(trans3d(x=AB.Good$Log.juvenile.growth.rate,y=rep(0.9,nrow(AB.Good)),
z=AB.Good$Log.adult.wt.mg, pmat = pmat), col = "black", pch =1,lwd=2,cex=1.5)

points(trans3d(x=AB.Poor$Log.juvenile.growth.rate,y=rep(0.1,nrow(AB.Poor)),
z=AB.Poor$Log.adult.wt.mg, pmat = pmat), col = "black", pch =1,lwd=2,cex=1.5)

points(trans3d(x=AD.Good$Log.juvenile.growth.rate,y=rep(0.9,nrow(AD.Good)),
z=AD.Good$Log.adult.wt.mg, pmat = pmat), col = "blue", pch =5,lwd=2,cex=1.3)

points(trans3d(x=AD.Poor$Log.juvenile.growth.rate,y=rep(0.1,nrow(AD.Poor)),
z=AD.Poor$Log.adult.wt.mg, pmat = pmat), col = "blue", pch =5,lwd=2,cex=1.3)

points(trans3d(x=AA.Good$Log.juvenile.growth.rate,y=rep(0.9,nrow(AA.Good)),
z=AA.Good$Log.adult.wt.mg, pmat = pmat), col = "red", pch =2,lwd=2,cex=1.3)

points(trans3d(x=AA.Poor$Log.juvenile.growth.rate,y=rep(0.1,nrow(AA.Poor)),
z=AA.Poor$Log.adult.wt.mg, pmat = pmat), col = "red", pch =2,lwd=2,cex=1.3)

text(locator(1),"(c)",cex=1.25); 

legend(locator(1),legend=c("Before", "During", "After"), 
pch=c(1,5,2), col=c("black","blue","red"),cex=1.5,bty="n",pt.lwd=2); 

