X=read.csv("Chemostat_Data_Teppo.csv");

######## extract a single run from the data file 
make.data=function(color,X,skip=0) {
    rot=paste("rot_",color,sep="");
    flag=paste("flag_",color,sep="");
    alg=paste("algae_",color,sep="");
    clump=paste("clumps_",color,sep="");
	d=paste("D_",color,sep="");
	Alg=Rot=Flag=Clump=D=rep(NA,nrow(X)); 
    ja=which(names(X)==alg); if(length(ja)>0) Alg=X[,ja];
    jr=which(names(X)==rot); if(length(jr)>0) Rot=X[,jr];
    jf=which(names(X)==flag); if(length(jf)>0) Flag=X[,jf];
    jc=which(names(X)==clump); if(length(jc)>0) Clump=X[,jc];
	jd=which(names(X)==d); if(length(jd)>0) D=X[,jd];
    out=data.frame(cbind(Alg,Flag,Rot,Clump,D));
	if(skip>0) out=out[-(1:skip),]; 
	
    
	# trim NA's from the bottom 
    while(sum(is.na(out[nrow(out),]))==5) {out=out[1:(nrow(out)-1),]}
 	#trim NA's from the top
	while(sum(is.na(out[1,]))==4) {out=out[2:nrow(out),]}
	
	names(out) <- c("Algae","Flag","Rot","Clump","D");
    return(out)
}

# scale so each pop has max=1, clumps -> clumps-1. 
popscale=function(mat) {
  pop=mat[,1:3];  
  pop=scale(pop,center=FALSE,scale=apply(pop,2,function(x) max(x,na.rm=TRUE)))
  return(pop)
}  

make.spline.smooth <- function(X,pwr=0.5) {
  fit.spline=smooth.spline(X[,1],X[,2]^pwr); 
  maxdf=nrow(X)/3; 
  if(fit.spline$df>maxdf) fit.spline=smooth.spline(X[,1],X[,2]^pwr,df=maxdf); 
  xvals=seq(min(X[,1]),max(X[,1]),length=500); 
  X2=predict(fit.spline,x=xvals)$y^(1/pwr); 
  return(list(x=xvals,y=X2));
}  

make.plot=function(color,vplot=NULL,skip=0){
  Run=make.data(color,X,skip); 
  days=1:nrow(Run); pops=popscale(Run);  
  clumps=Run[,"Clump"]; cmax=max(clumps,na.rm=T); 
  cmax=quantile(clumps,0.975,na.rm=T); clumps[clumps>cmax] = NA; 
  Cdata=na.omit(cbind(days,clumps)); 

  matplot(days,pops,col=c("green4","purple","red"),type="p", lwd=2,
          lty=2,pch=c(1,17,16),xlab=" ",ylab="Scaled Populations",cex=1);
   # title(main=color,adj=1)       

   Fmax=max(Run[,"Flag"],na.rm=TRUE); 
   #par(xpd=TRUE); text(0,1.07,paste("Fmax=",round(Fmax))); par(xpd=FALSE); 
	  
  Adata=na.omit(cbind(days,pops[,1])); 	
  if(nrow(Adata)>9) {
  out=make.spline.smooth(Adata);
  points(out$x,out$y,type="l",col="green4",lwd=2) 
  }
  
  Fdata=na.omit(cbind(days,pops[,2])); 	
  if(nrow(Fdata)>9) {
  out=make.spline.smooth(Fdata);
  points(out$x,out$y,type="l",col="purple",lwd=2) 
  }	

  Rdata=na.omit(cbind(days,pops[,3])); 	
  if(nrow(Rdata)>9) {
  out=make.spline.smooth(Rdata);
  points(out$x,out$y,type="l",col="red",lwd=2) 
  }
  if(!is.null(vplot)) abline(v=vplot,lty=2); 
 
  return(Run); 
}  

par(mfrow=c(2,1),mar=c(4,4,2,1) + 0.1,mgp=c(2.25,1,0),cex.axis=1.35,cex.lab=1.5);
R=make.plot("red4",skip=28);
panelLabel("(a)"); 

R=make.plot("pink",skip=94); 
panelLabel("(b)"); 
mtext("Time (days)",side=1,adj=0.5,line=2,cex=1.6)



