require(deSolve); 
source("DynamicsFunctions=Tansley.R"); 

set.seed(1244123); 

panelLabel=function(text) mtext(text,side=3,adj=0,cex=1.35,line=0.35); 

peaks<-function(series,span=3) {
  if((span <- as.integer(span)) %% 2 != 1) stop("'span' must be odd")
  z = embed(series, span)
  s=(span-1)/2; 	
  zmid=z[,(1+span)/2]; zother=z[,-(1+span)/2]; zomax=apply(zother,1,max);
  v=(zmid>zomax);
  pad = rep(FALSE, s)
  result = c(pad, v, pad)
  return(result) 
} 

graphics.off(); 
dev.new(width=10,height=5.5);
mat=matrix(c(1,2,3,4,4,5),2,3,byrow=TRUE)
layout(mat)
par(mgp=c(2.5,1,0),cex.axis=1.4,cex.lab=1.75,mar=c(4,4,2,1),xpd=TRUE);

###########################################################################
### Two prey clones, "Incompatible defense traits" IC
#############################################################################
delta=1.1; r=2/delta; g=2.2/delta; K=0.35; 
eta=0.5; h=4; K=0.35 # for the paper 
p1=0.05; p1z=0.1; pvals=c(p1,1,p1,1); pivals=c(1,1,p1z,p1z); nprey=length(pvals); 
k2=.03; k1=3*k2; 
kvals=k2+0.5*(k1-k2)*(2-pvals-pivals)
kadjust=c(1.2,  1000,
	      1000,  1); 
kvals=kvals*kadjust; 

out=Dynamics.plot(model="IC",xlab="",ylab="Populations"); 
panelLabel("(a)")
 
# Save these: wild stuff! 
delta=1; r=3.3/delta; g=2.5/delta; K=0.2; 
 eta=2; h=5; 
p1=0.05; p1z=0.05; pvals=c(p1,1,p1,1); pivals=c(1,1,p1z,p1z); nprey=length(pvals); 
k2=.05; k1=2*k2; 
kvals=k2+0.5*(k1-k2)*(2-pvals-pivals)
kadjust=c(2,  1000,
	      1000,  1); 
kvals=kvals*kadjust; 
out=Dynamics.plot(model="IC"); 
panelLabel("(b)")

#############################################################################
### Clones 1 and 2 (x_z and x_2), "Ignore the intermediate", IC 
#############################################################################

#################### Save these! 
delta=1; r=2/delta; g=2.2/delta; K=0.25; 
p1=0.05; p1z=0.05; pvals=c(p1,1,p1,1); pivals=c(1,1,p1z,p1z); nprey=length(pvals); 
k2=.03; k1=3*k2; 

h=3; eta=2    #y in phase with total prey, z out of phase 
kvals=k2+0.5*(k1-k2)*(2-pvals-pivals)
kadjust= c(1, 1.2,
	       100, 100); 
kvals=kvals*kadjust; 
out=Dynamics.plot(model="IC"); 
panelLabel("(c)")

#h=4; eta=2; # Bursting-type oscillations 
#out=Dynamics.plot(model="IC",ylab="Populations"); 
#panelLabel("(d)")

#############################################################################
### "Can't beat both": x2,xy,xz (clones 1,3,4), IC  
#############################################################################

delta=1; r=2/delta; g=2.2/delta; K=0.195; 
eta=2; h=5; 
p1=0.05; p1z=0.1; pvals=c(p1,1,p1,1); pivals=c(1,1,p1z,p1z); nprey=length(pvals); 
k2=.03; k1=10*k2; 
kvals=k2+0.5*(k1-k2)*(2-pvals-pivals)
kadjust=c(1.1,   1,
	      1000,  1); 
kvals=kvals*kadjust; 
out=Dynamics.plot(model="IC",ylab="Populations",runtime=150); 
panelLabel("(d)")
mtext("Time (days)",side=1,adj=1,cex=1.25,line=2.5); 



ICQT=function(t,X,parms) {
	X1=pmax(X,0); 
	x=X1[1]; y=X1[2]; z=X1[3]; f=X1[4]; 
	k=f*k2+(1-f)*k1;
	p=f*p2^a+(1-f)*p1^a; p=p^(1/a); 
	Pi=f*Pi2^a+(1-f)*Pi1^a; Pi=Pi^(1/a);
	Q=p*x; R=Pi*x; S = max(0,1 - x - y - z);  
	Fy=g*y/(K+Q);  
	xdot=x*(r*S/(k+S)- p*Fy - Pi*h*z-1); # prey
	ydot=Fy*Q + eta*z*y - y; 		#predator 1 
	zdot=z*(h*R - eta*y - 1);		#predator 2 (intermediate)
	
	df1 = -(r * S * k1 * (k2 - k1))/((k1 * f * (k2 - k1) + S) ^ 2) ;
    df2 = -g * y* (p2 ^ a - p1 ^ a)*((p1 ^ a + f * (p2 ^ a - p1 ^ a))^(1/a))/ (a * (p1 ^ a + f * (p2 ^ a - p1 ^ a)) * (K + Q));
    df3 = -h * z* (Pi2 ^ a - Pi1 ^ a)*((Pi1 ^ a + f * (Pi2 ^ a - Pi1 ^ a))^(1/a))/ (a * (Pi1 ^ a + f * (Pi2 ^ a - Pi1 ^ a)));
    df=parms[1]*f*(1-f)*(df1+df2+df3) 
	
	dx=c(xdot,ydot,zdot,df); dx[X<=0]=0; dx[X>=1]=0; dx[!is.finite(dx)]=0;  
	return(list(xdot=dx,p,Pi,df1,df2,df3,df))
}

delta=1; r=2/delta; g=2.3/delta; 
eta=.25; h=15; K=0.2 # for the paper 
p1=0.0; p2=1; 
Pi1=1; Pi2=0.0;   
k2=0.03; k1=k2; a=.65
h=14; 

tvals=seq(0,1000,by=.25); 
y0=c(0.5*runif(1),0.25*runif(2),0.05+0.9*runif(1)); 
out=data.frame(lsoda(y0,times=tvals,fun=ICQT,parms=.25)); 
names(out)<-c("time","X","y","z","f","p","Pi","df1","df2","df3","df") 

######### prey-type frequencies 
plottime=30; 
e=tvals>(max(tvals)-plottime); tmin=min(tvals[e]); tvals=tvals-tmin; 
matplot(tvals[e],cbind(out$X,out$y,out$z)[e,],type="l",pch=c(1,16,17),lty=1,lwd=2,col=c("green4","red","purple"),
	xlab="",ylab="",bty="l",cex=2); 

px=tvals[e]; py=cbind(out$X,out$y,out$z)[e,];
ee=which(px%%1==0); 
matpoints(px[ee],py[ee,],type="p",pch=c(1,16,17),lwd=2,col=c("green4","red","purple"),
	xlab="",ylab="",bty="l",cex=2); 	
	
panelLabel("(e)")	
